#!/bin/bash
# http://audacious-media-player.org
REPO=http://zenwalk.pinguix.com/user-accounts/tilderb/extra/xap/audacious
#
which audtool2 2>/dev/null && { echo "UnInstall audacious first!"; exit 1; }
which fakeroot 2>/dev/null || { echo "Need fakeroot/sudo installed - or edit this script!"; exit 1; }
which convert 2>/dev/null || { echo "Need imagemagick installed"; exit 1; }
#
# script by: til <rob DOT til DOT freedman AT googlemail DOT com>
set -u -e -x

# audacious
version=2.2
build=64.1
arch=i686
tune=pentium-m

pkgname=audacious-$version
package=$pkgname-$arch-$build

PKG_DEP='atk,cairo,dbus,dbus-glib,expat,fontconfig,freetype,gcc,gcc-g++,glib2,gtk+2,libICE,libSM,libX11,libXau,libXcomposite,libXcursor,libXdamage,libXdmcp,libXext,libXfixes,libXi,libXinerama,libXrandr,libXrender,libmcs,libmowgli,libpng,libsamplerate,libxcb,pango,pixman,util-linux-ng,zlib'

PKG_SRC="$REPO/build-audacious.sh
$REPO/jack_free.patch
$REPO/audacious-2.2-disabled-iplugins.patch
$REPO/audacious-2.2-AUD-99.patch
$REPO/audacious-2.2-pkgconfig-libs.patch
$REPO/audacious-2.2-multiple-decoders-per-ext.patch
$REPO/audacious-2.2-set_tuple_cb.patch
$REPO/audacious-2.2-libm.patch
$REPO/audacious-2.2-coverart.patch
http://distfiles.atheme.org/audacious-$version.tgz"
#
CWD=$(pwd)
TMP=${TMP:-$CWD/tmp}
PKG=$TMP/$package

[ -d $PKG ] && rm -fr $PKG
mkdir -p $PKG/{install,usr/{src,doc}/$pkgname}
#
cd $TMP
( rm -fr audacious-plugins-$version audacious-$version )

tar xf $CWD/audacious-$version.tgz

# base
cd $TMP/audacious-$version
patch -Np1 -i $CWD/audacious-2.2-disabled-iplugins.patch
patch -Np1 -i $CWD/audacious-2.2-AUD-99.patch
patch -Np1 -i $CWD/audacious-2.2-pkgconfig-libs.patch
patch -Np1 -i $CWD/audacious-2.2-multiple-decoders-per-ext.patch
patch -Np1 -i $CWD/audacious-2.2-set_tuple_cb.patch
patch -Np1 -i $CWD/audacious-2.2-libm.patch
patch -Np1 -i $CWD/audacious-2.2-coverart.patch

./configure --help >$CWD/configure-base

CFLAGS="-O2 -march=$arch -mtune=$tune" \
CXXFLAGS="-O2 -march=$arch -mtune=$tune" \
  ./configure \
    --prefix=/usr \
	--mandir=/usr/man \
    --enable-samplerate 
    
sed -i "s/UNSUPPORTED VERSION/Zenwalk package/g" src/audacious/Makefile

# sed -i "s/^\.SILENT://g" buildsys.mk
make || exit 1
make install DESTDIR=$PKG

# hack allows building in one go
sudo cp -a $PKG/usr/{include,lib} /usr
sudo ldconfig
rm -fr $PKG/usr/{include,lib/pkgconfig}
echo "sudo rm -fr /usr/include/{audacious,libaudgui,libaudtag,libaudcore,libSAD} /usr/lib/pkgconfig/{audacious.pc,audclient.pc}"  >$CWD/rm-dev-files.sh

#docs
cp -a AUTHORS COPYING NEWS README $PKG/usr/doc/$pkgname

cd $PKG
# strip binaries
find usr | xargs file | grep -e "executable" -e "shared object" | grep ELF | cut -f 1 -d : | \
	xargs -r strip --strip-unneeded 2> /dev/null

# zip man pages
find usr/man -type f -name "*.?" | xargs gzip -9

# icons
mkdir -p  usr/share/icons/hicolor/{16x16,24x24,32x32,48x48}/apps

for size in 16x16 24x24 32x32; do
	convert -resize $size usr/share/pixmaps/audacious2.png \
	  		usr/share/icons/hicolor/$size/apps/audacious2.png
done
mv usr/share/pixmaps/audacious2.png \
			usr/share/icons/hicolor/48x48/apps/audacious2.png
rm -fr usr/share/pixmaps

# slackdesc
#        |-----handy-ruler-------------------------------------------------------|
cat <<EOF > install/slack-desc
audacious: audacious (GTK2 based audio player)
audacious:
audacious: Audacious is used to play audio and other kinds of media files.
audacious:
audacious: By default, Audacious can play MPEG audio, Ogg Vorbis, RIFF wav,
audacious: most module formats, and many others ...
EOF
#
# buildscript
cp $CWD/build-audacious.sh usr/src/$pkgname

mkdir -p usr/share/audacious/Skins/Zenwalk
tar xf $CWD/Zenwalk-theme.tar.gz --strip-components=1 -C usr/share/audacious/Skins/Zenwalk
#

fakeroot /sbin/makepkg -l y -c n $CWD/$package.txz
#
cd $CWD
echo "$PKG_SRC" >$package.src
echo -n $PKG_DEP > $package.dep
md5sum $package.txz > $package.md5
